@@ -59,6 +59,7 @@ class BuildServiceJobOutput;
 class BuildServiceJob;
 class BuildService;
 class PrivateData;
+class Config;
 class Content;
 class DownloadItem;
 class Distribution;
@@ -271,6 +272,12 @@ public:
     */
     PostJob *checkLogin(const QString &user, const QString &password);
 
+    /**
+     * Fetches server config
+     * @return The job responsible for fetching data
+     */
+    ItemJob<Config> *requestConfig();
+
     // Person part of OCS
 
     PostJob *registerAccount(const QString &id, const QString &password, const QString &mail, const QString &firstName, const QString &lastName);
@@ -579,15 +586,19 @@ public:
      */
     ItemJob<Content> *requestContent(const QString &contentId);
 
-    ItemJob<DownloadItem> *downloadLink(const QString &contentId, const QString &itemId = QLatin1String("1"));
+    ItemJob<DownloadItem> *downloadLink(const QString &contentId, const QString &itemId = QStringLiteral("1"));
 
+#if ATTICA_ENABLE_DEPRECATED_SINCE(0, 2)
     /** Vote for a content item
      * This version is for the old OCS API < 1.6
      * @param contentId the content which this voting is for
      * @param positiveVote whether the voting is positive or negative
      * @return the post job for this voting
+     * @deprecated Since 0.2, use voteForContent(const QString &, uint)
      */
-    Q_DECL_DEPRECATED PostJob *voteForContent(const QString &contentId, bool positiveVote);
+    ATTICA_DEPRECATED_VERSION(0, 2, "Use Provider::voteForContent(const QString &, uint)")
+    PostJob *voteForContent(const QString &contentId, bool positiveVote);
+#endif
 
     /** Vote for a content item
      * @param contentId the content which this voting is for
@@ -670,6 +681,7 @@ protected:
     // Convenience overload
     QNetworkRequest createRequest(const QString &path);
 
+    ItemJob<Config> *doRequestConfig(const QUrl &url);
     ItemJob<Person> *doRequestPerson(const QUrl &url);
     ItemJob<AccountBalance> *doRequestAccountBalance(const QUrl &url);
     ListJob<Person> *doRequestPersonList(const QUrl &url);
